@@ -1,6 +1,6 @@
 #Plot a graph with nodes in modules indicated by colors
 
-PlotGraphWithModules <- function(Adj_directed,PlotDendrogramObj,GV=GV,node.size=8,arrow.size = 5,label.size = 3,alpha = 1,...) {
+PlotGraphWithModules <- function(Adj_directed,PlotDendrogramObj,GV,node.size=8,arrow.size = 5,label.size = 3,alpha = 1,...) {
   
   
   AC <- PlotDendrogramObj$dynamicColors #All (genes and GV) colors
